==> sinetstream-1.5.0.tar.gz: sinetstream-1.5.0/src/sinetstream/__init__.py <==
# Copyright (C) 2019 National Institute of Informatics
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from .api import (
    MessageReader, MessageWriter, AsyncMessageWriter, AsyncMessageReader,
    AT_MOST_ONCE, AT_LEAST_ONCE, EXACTLY_ONCE, DEFAULT_CLIENT_ID,
    Metrics,
)
from .error import (
    SinetError, NoServiceError, NoConfigError, InvalidArgumentError,
    ConnectionError, AlreadyConnectedError, UnsupportedServiceTypeError,
    InvalidMessageError, AuthorizationError,
)
from .value_type import TEXT, BYTE_ARRAY

__all__ = [
    MessageReader, MessageWriter, AsyncMessageWriter, AsyncMessageReader,
    AT_MOST_ONCE, AT_LEAST_ONCE, EXACTLY_ONCE, DEFAULT_CLIENT_ID,
    Metrics,

    SinetError, NoServiceError, NoConfigError, InvalidArgumentError,
    ConnectionError, AlreadyConnectedError, UnsupportedServiceTypeError,
    InvalidMessageError, AuthorizationError,

    TEXT, BYTE_ARRAY
]

==> sinetstream-1.6.0.tar.gz: sinetstream-1.6.0/src/sinetstream/__init__.py <==
# Copyright (C) 2019 National Institute of Informatics
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from .api import (
    MessageReader, MessageWriter, AsyncMessageWriter, AsyncMessageReader,
    AT_MOST_ONCE, AT_LEAST_ONCE, EXACTLY_ONCE, DEFAULT_CLIENT_ID,
    Metrics,
)
from .error import (
    SinetError, NoServiceError, NoConfigError, InvalidArgumentError,
    ConnectionError, AlreadyConnectedError, UnsupportedServiceTypeError,
    InvalidMessageError, AuthorizationError, InvalidConfigError,
)
from .value_type import TEXT, BYTE_ARRAY

__all__ = [
    MessageReader, MessageWriter, AsyncMessageWriter, AsyncMessageReader,
    AT_MOST_ONCE, AT_LEAST_ONCE, EXACTLY_ONCE, DEFAULT_CLIENT_ID,
    Metrics,

    SinetError, NoServiceError, NoConfigError, InvalidArgumentError,
    ConnectionError, AlreadyConnectedError, UnsupportedServiceTypeError,
    InvalidMessageError, AuthorizationError, InvalidConfigError,

    TEXT, BYTE_ARRAY
]
